/**
 * Copyright (c) 2004, yher2 project
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, 
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, 
 *   this list of conditions and the following disclaimer in the documentation 
 *   and/or other materials provided with the distribution.
 * * Neither the name of the nor the names of its contributors may be used to endorse or 
 *   promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */
package net.yher2.junit.db;

import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;

import org.apache.commons.dbutils.DbUtils;

import net.yher2.commons.io.Path;

import junit.framework.TestCase;

/**
 * @auther  hisaboh
 */
public abstract class DBTestCase extends TestCase {
	protected abstract Connection getConnection() throws SQLException;
	
	/**
	 * 
	 */
	public DBTestCase() {
		super();
	}
	/**
	 * @param name
	 */
	public DBTestCase(String name) {
		super(name);
	}
	/**
	 * eXgf[^f[^x[XɗpӂB
	 * @param testData eXgf[^̃t@C(Excel)ւ̃pX
	 * @throws IOException
	 * @throws SQLException
	 */
	protected void prepare(Path testData) throws IOException, SQLException {
		Connection con = null;
		try {
			con = getConnection();
			con.setAutoCommit(false);
			prepare(con, testData);
			con.commit();
		} finally {
			DbUtils.rollback(con);
			DbUtils.close(con);
		}
	}
	protected void prepare(Connection con, Path testData) throws IOException, SQLException {
		TestDataManager manager = new TestDataManager(con);
		manager.prepare(testData);
	}
	
	/**
	 * eXgf[^f[^x[XB
	 * @param testData eXgf[^̃t@C(Excel)ւ̃pX
	 * @throws IOException
	 * @throws SQLException
	 */
	protected void clear(Path testData) throws IOException, SQLException {
		Connection con = null;
		try {
			con = getConnection();
			con.setAutoCommit(false);
			clear(con, testData);
			con.commit();
		} finally {
			DbUtils.rollback(con);
			DbUtils.close(con);
		}
	}
	protected void clear(Connection con, Path testData) throws IOException, SQLException {
		TestDataManager manager = new TestDataManager(con);
		manager.clear(testData);
	}
}
